@@ -1,11 +1,13 @@
 package Mongoose::Join;
-$Mongoose::Join::VERSION = '0.32';
+$Mongoose::Join::VERSION = '0.33';
 use Moose;
 use Moose::Util::TypeConstraints;
 use Moose::Meta::TypeConstraint::Parameterizable;
 use Moose::Meta::TypeConstraint::Registry;
 use Tie::IxHash;
 
+my $API_V1 = Mongoose->_mongodb_v1;
+
 my $REGISTRY = Moose::Meta::TypeConstraint::Registry->new;
 $REGISTRY->add_type_constraint(
     Moose::Meta::TypeConstraint::Parameterizable->new(
@@ -20,8 +22,7 @@ $REGISTRY->add_type_constraint(
     )
 );
 
-Moose::Util::TypeConstraints::add_parameterizable_type(
-    $REGISTRY->get_type_constraint('Mongoose::Join') );
+Moose::Util::TypeConstraints::add_parameterizable_type( $REGISTRY->get_type_constraint('Mongoose::Join') );
 
 has 'class'                 => ( is => 'rw', isa => 'Str' );
 has 'field'                 => ( is => 'rw', isa => 'Str' );
@@ -30,7 +31,7 @@ has '_with_collection_name' => ( is => 'rw', isa => 'Str' );
 has 'parent'                => ( is => 'rw', isa => 'MongoDB::OID' );
 
 # once the object is expanded, it has children too
-has 'children'              => ( is => 'rw', isa => 'ArrayRef' );
+has 'children'              => ( is => 'rw', isa => 'ArrayRef', default => sub{[]} );
 
 # before being saved, objects are stored in this buffer
 has 'buffer' => ( is => 'rw', isa => 'HashRef', default => sub { {} } );
@@ -45,6 +46,7 @@ sub add {
     for my $obj (@objs) {
         $self->buffer->{ refaddr $obj } = $obj;
     }
+    @objs;
 }
 
 sub remove {
@@ -61,10 +63,10 @@ sub remove {
     # children get cleaned too
     if( defined ( my $children = $self->children ) ) {
         for my $obj (@objs) {
-            my $id = $obj->{_id};
-            next unless defined $id; 
+            my $id = $obj->_id;
+            next unless defined $id;
             $self->children([
-                grep { $_->FETCH('$id') ne $id } _tie_refs( @{$children} )
+                grep { _rel_id($_) ne $id } _build_rel( @{$children} )
             ]);
         }
     }
@@ -102,7 +104,7 @@ sub _save {
     if( ref $children eq 'Mongoose::Join' ) {
         $children = $children->children;
     }
-    my @objs = _tie_refs( @{$children ||[]} );
+    my @objs = _build_rel( @{$children ||[]} );
 
     my $collection_name = $self->with_collection_name;
 
@@ -115,7 +117,7 @@ sub _save {
         my $obj = delete $buffer->{$_};
         next if exists $delete_buffer->{ refaddr $obj };
         $obj->save( @scope );
-        push @objs, Tie::IxHash->new( '$ref' => $collection_name, '$id' => $obj->_id );
+        push @objs, _build_rel({ '$ref' => $collection_name, '$id' => $obj->_id });
     }
 
     # adjust
@@ -123,7 +125,7 @@ sub _save {
     $self->delete_buffer({});
 
     # make sure unique children is saved
-    my %unique = map { $_->FETCH('$id') => $_ } @objs;
+    my %unique = map { _rel_id($_) => $_ } @objs;
     @objs = values %unique;
     $self->children( \@objs );
     return @objs;
@@ -133,7 +135,7 @@ sub _children_refs {
     my ($self)=@_;
     my @found;
     $self->find->each( sub{
-        push @found, Tie::IxHash->new( '$ref' => $_[0]->_collection_name, '$id' => $_[0]->{_id} );
+        push @found, _build_rel( '$ref' => $_[0]->_collection_name, '$id' => $_[0]->{_id} );
     });
     return @found;
 }
@@ -146,7 +148,7 @@ sub find {
     if( ref $children eq 'Mongoose::Join' ) {
         $children = $children->children;
     }
-    my @children = map { $_->FETCH('$id') } _tie_refs( @{$children ||[]} );
+    my @children = map { _rel_id($_) } _build_rel( @{$children ||[]} );
 
     $opts->{_id} = { '$in' => \@children };
     return $class->find( $opts, @scope );
@@ -156,7 +158,7 @@ sub find_one {
     my ( $self, $opts, @scope ) = @_;
     my $class = $self->with_class;
     $opts ||= {};
-    my @children = map { $_->FETCH('$id') } _tie_refs( @{$self->children ||[]} );
+    my @children = map { _rel_id($_) } _build_rel( @{$self->children ||[]} );
     $opts->{_id} = { '$in' => \@children };
     return $class->find_one( $opts, @scope );
 }
@@ -170,7 +172,7 @@ sub query {
     my ( $self, $opts, $attrs, @scope ) = @_;
     my $class = $self->with_class;
     $opts ||= {};
-    my @children = map { $_->{'$id'} } @{ $self->children || [] };
+    my @children = map { _rel_id($_) } _build_rel( @{$self->children ||[]} );
     $opts->{_id} = { '$in' => \@children };
     return $class->query( $opts, $attrs, @scope );
 }
@@ -200,16 +202,24 @@ sub hash_array {
     return %hash;
 }
 
-# make sure all refs are sorted hashes
-sub _tie_refs {
+# make sure all refs what's expected on the MongoDB driver in use
+sub _build_rel {
     for (@_) {
-        $_ = Tie::IxHash->new( '$ref'=>$_->{'$ref'}, '$id'=>$_->{'$id'})
-            unless ref $_ eq 'Tie::IxHash';
+        if ($API_V1) {
+            $_ = MongoDB::DBRef->new( ref => $_->{'$ref'}, id => $_->{'$id'} )
+                unless ref $_ eq 'MongoDB::DBRef';
+        }
+        else {
+             $_ = Tie::IxHash->new( '$ref' => $_->{'$ref'}, '$id' => $_->{'$id'} )
+                unless ref $_ eq 'Tie::IxHash';
+        }
     }
-
     @_;
 }
 
+# Read rel ID from ref type in use depending on driver version
+sub _rel_id { $API_V1 ? $_[0]->id : $_[0]->FETCH('$id') }
+
 =head1 NAME
 
 Mongoose::Join - simple class relationship resolver
